==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/lib/layersmenu-header.inc.php <==
<!-- PHP Layers Menu 1.0.0 (c) 2001 Marco Pratesi <pratesi@telug.it> -->

<?php
$abscissa_step = 140;			// step for the left boundaries of layers
$abscissa_offset = 20;			// to choose the horizontal coordinate start offset for the layers
$abscissa_stepx5 = $abscissa_step*5;
$rightarrow = " &middot;&middot;&middot;&gt;";
// the following is to support browsers not detecting the mouse position
$ordinata_step = 15;			// estimated value of the number of pixels between links on a layer
$ordinata[2] = 200-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
?>

<script language="JavaScript">
<!--
var thresholdY = 15;		// in pixels; threshold for vertical repositioning of a layer
var ordinata_margin = 20;	// to start the layer a bit above the mouse vertical coordinate

DOM = (document.getElementById) ? 1 : 0;
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
var loaded = 0;	// to avoid stupid errors of Microsoft browsers
// -->
</script>

<script language="JavaScript1.2">
<!--

// it works with NS4, Mozilla, NS6, Opera 5, IE
currentY = -1;
function grabMouse(e) {
	if (DOM && !IE4) {
		currentY = e.clientY;
	} else if (NS4) {
		currentY = e.pageY;
	} else {
		currentY = event.y;
	}
	if (DOM && !IE4 && navigator.appName != "Opera") {
		currentY += window.pageYOffset;
	} else if (IE4 && DOM) {
		currentY += document.body.scrollTop;
	}
}
if ((DOM || NS4) && !IE4) {
	document.captureEvents(Event.MOUSEDOWN | Event.MOUSEMOVE);
}
document.onmousemove = grabMouse;

function popUp(menuName,on) {
	if (loaded) {	// to avoid stupid errors of Microsoft browsers
		if (on) {
//			moveLayers();
			if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
			} else if (NS4) {
				document.layers[menuName].visibility = "show";
			} else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?php

$qid_bcjs = new PGM_Sql;
$qid_bcjs->begin();
build_catbrowser_js(&$qid_bcjs, $categories);
$qid_bcjs->commit();
$qid_bcjs->close();
$categories = ".Top^" . "$CFG->wwwroot" . "/shopping/\n" . $categories;
//echo $categories;

$moveLayersDOM = "";
$moveLayersNS4 = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ******************************************************************** */
/* Taken from TreeMenu 1.0 (c) 1999 by Bjorge Dijkstra - bjorge@gmx.net */
/* ******************************************************************** */
/* with some changes */

$maxlevel=0;
$cnt=0;

while ($categories != "") {
	$beforecr = strcspn($categories,"\n");
	$buffer = substr($categories,0,$beforecr);
	$categories = substr (stristr ($categories, 10), 1 );
	$buffer = ereg_replace(chr(13), "", $buffer);	// Microsoft Stupidity Suppression
	$tree[$cnt][0] = strspn($buffer, ".");
	$tmp = rtrim(substr($buffer, $tree[$cnt][0]));
	$node = explode("^", $tmp);
	$tree[$cnt][1] = $node[0];
	$layer_label[$cnt] = "L" . $cnt;
	$tree[$cnt][2] = (ereg_replace(" ", "", $node[1]) == "") ? "#" : $node[1];
	$tree[$cnt][3] = $node[2];
	$tree[$cnt][4] = 0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}

/* ******************************************************************** */

for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step + $abscissa_offset;

for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
	// assign the layers name to the current hierarchical level,
	// to keep trace of the route leading to the current node on the tree
	$layername[$tree[$cnt][0]] = $layer_label[$cnt];

	// assign the starting vertical coordinates for all sublevels
	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++)
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	// increment the starting vertical coordinate for the current sublevel
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// the node is not a leaf, hence it has at least a child
		// prepare the popUp function related to the children
		echo "function popUp" . $layer_label[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=2; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		// geometrical parameters are assigned to the new layer, related to the above mentioned children
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersNS4 .= "document.layers['" . $layer_label[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $layer_label[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		// the new layer is accounted for in the shutdown() function
		$shutdown .= "popUp('" . $layer_label[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 2) {	// the hierarchical level is > 2, hence the current node is not a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
/* */
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
/* */
/*
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
*/
	}

	if ($tree[$cnt][0] == 2) {	// the hierarchical level is = 2, hence the current node is a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"shutdown();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
	}

}	// end of the "for" cycle scanning all nodes

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (DOM) {
<?php echo $moveLayersDOM; ?>
} else if (NS4) {
<?php echo $moveLayersNS4; ?>
} else {
<?php echo $moveLayersDef; ?>
}
}
<?php echo $shutdown; ?>

function moveLayerY(menuName, ordinata) {
if (loaded) {	// to avoid stupid errors of Microsoft browsers
<?php
//alert (ordinata);
// Konqueror: ordinata = -1 according to the initialization currentY = -1
// Opera: isNaN(ordinata), currentY is NaN, it seems that Opera ignores the initialization currentY = -1
?>
if (ordinata != -1 && !isNaN(ordinata)) {	// The browser has detected the mouse position
if (DOM) {
<?php /* attenzione a "px" !!! */ ?>
	appoggio = parseInt(document.getElementById(menuName).style.top);
	if (isNaN(appoggio)) appoggio = 0;
	if (Math.abs(appoggio + ordinata_margin - ordinata) > thresholdY)
		document.getElementById(menuName).style.top = ordinata - ordinata_margin;
} else if (NS4) {
	if (Math.abs(document.layers[menuName].top + ordinata_margin - ordinata) > thresholdY)
		document.layers[menuName].top = ordinata - ordinata_margin;
} else {
	if (Math.abs(document.all[menuName].style.pixelTop + ordinata_margin - ordinata) > thresholdY)
		document.all[menuName].style.pixelTop = ordinata - ordinata_margin;
}
}
}
}

// -->
</script>

<!-- PHP Layers Menu 1.0.0 (c) 2001 Marco Pratesi <pratesi@telug.it> -->

==> pgmarket-1.5.3.tar.gz: pgmarket-1.5.3/lib/layersmenu-header.inc.php <==
<!-- PHP Layers Menu 1.0.1 (c) 2001 Marco Pratesi <pratesi@telug.it> -->

<?php
$abscissa_step = 100;			// step for the left boundaries of layers
$abscissa_offset = -20;			// to choose the horizontal coordinate start offset for the layers
$abscissa_stepx5 = $abscissa_step*5;
$rightarrow = " &middot;&middot;&middot;&gt;";
// the following is to support browsers not detecting the mouse position
$ordinata_step = 15;			// estimated value of the number of pixels between links on a layer
$ordinata[1] = 200-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
?>

<script language="JavaScript">
<!--
var thresholdY = 15;		// in pixels; threshold for vertical repositioning of a layer
var ordinata_margin = 20;	// to start the layer a bit above the mouse vertical coordinate

DOM = (document.getElementById) ? 1 : 0;
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
var loaded = 0;	// to avoid stupid errors of Microsoft browsers
Opera5 = (navigator.userAgent.indexOf("Opera 5") > -1) ? 1 : 0;
// -->
</script>

<script language="JavaScript1.2">
<!--

// it works with NS4, Mozilla, NS6, Opera 5, IE
currentY = -1;
function grabMouse(e) {
	if ((DOM && !IE4) || Opera5) {
		currentY = e.clientY;
	} else if (NS4) {
		currentY = e.pageY;
	} else {
		currentY = event.y;
	}
	if (DOM && !IE4 && !Opera5) {
		currentY += window.pageYOffset;
	} else if (IE4 && DOM && !Opera5) {
		currentY += document.body.scrollTop;
	}
}
if ((DOM || NS4) && !IE4) {
	document.captureEvents(Event.MOUSEDOWN | Event.MOUSEMOVE);
}
document.onmousemove = grabMouse;

function popUp(menuName,on) {
	if (loaded) {	// to avoid stupid errors of Microsoft browsers
		if (on) {
//			moveLayers();
			if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
			} else if (NS4) {
				document.layers[menuName].visibility = "show";
			} else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?php

$qid_bcjs = new PGM_Sql;
$qid_bcjs->begin();
build_catbrowser_js(&$qid_bcjs, $categories);
$qid_bcjs->commit();
//echo $categories;

$moveLayersDOM = "";
$moveLayersNS4 = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ********************************************************** */
/* Taken from TreeMenu 1.1 - Bjorge Dijkstra (bjorge@gmx.net) */
/* ********************************************************** */
/* with some changes */

$maxlevel=0;
$cnt=1;

while ($categories != "") {
	$beforecr = strcspn($categories,"\n");
	$buffer = substr($categories,0,$beforecr);
	$categories = substr (stristr ($categories, 10), 1 );
	$buffer = ereg_replace(chr(13), "", $buffer);	// Microsoft Stupidity Suppression
	$tree[$cnt][0] = strspn($buffer, ".");
	$tmp = rtrim(substr($buffer, $tree[$cnt][0]));
	$node = explode("^", $tmp);
	$tree[$cnt][1] = $node[0];
	$layer_label[$cnt] = "L" . $cnt;
	$tree[$cnt][2] = (ereg_replace(" ", "", $node[1]) == "") ? "#" : $node[1];
	$tree[$cnt][3] = $node[2];
	$tree[$cnt][4] = 0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}

/* ******************************************************************** */

for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step + $abscissa_offset;

for ($cnt=1; $cnt<=count($tree); $cnt++) {	// this counter scans all nodes
	// assign the layers name to the current hierarchical level,
	// to keep trace of the route leading to the current node on the tree
	$layername[$tree[$cnt][0]] = $layer_label[$cnt];

	// assign the starting vertical coordinates for all sublevels
	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++)
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	// increment the starting vertical coordinate for the current sublevel
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// the node is not a leaf, hence it has at least a child
		// prepare the popUp function related to the children
		echo "function popUp" . $layer_label[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=1; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		// geometrical parameters are assigned to the new layer, related to the above mentioned children
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $layer_label[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersNS4 .= "document.layers['" . $layer_label[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $layer_label[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $layer_label[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		// the new layer is accounted for in the shutdown() function
		$shutdown .= "popUp('" . $layer_label[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 1) {	// the hierarchical level is > 1, hence the current node is not a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
/* */
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
/* */
/*
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
*/
	}

	if ($tree[$cnt][0] == 1) {	// the hierarchical level is = 1, hence the current node is a child of the root node
		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"moveLayerY('" . $layer_label[$cnt] . "', currentY) ; popUp" . $layer_label[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
		} else {	// a leaf
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"shutdown();\">" . stripslashes($tree[$cnt][1]) . "</a><br>\n";
		}
	}

}	// end of the "for" cycle scanning all nodes

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (DOM) {
<?php echo $moveLayersDOM; ?>
} else if (NS4) {
<?php echo $moveLayersNS4; ?>
} else {
<?php echo $moveLayersDef; ?>
}
}
<?php echo $shutdown; ?>

function moveLayerY(menuName, ordinata) {
if (loaded) {	// to avoid stupid errors of Microsoft browsers
<?php
//alert (ordinata);
// Konqueror: ordinata = -1 according to the initialization currentY = -1
// Opera: isNaN(ordinata), currentY is NaN, it seems that Opera ignores the initialization currentY = -1
?>
if (ordinata != -1 && !isNaN(ordinata)) {	// The browser has detected the mouse position
if (DOM) {
<?php /* attenzione a "px" !!! */ ?>
	appoggio = parseInt(document.getElementById(menuName).style.top);
	if (isNaN(appoggio)) appoggio = 0;
	if (Math.abs(appoggio + ordinata_margin - ordinata) > thresholdY)
		document.getElementById(menuName).style.top = ordinata - ordinata_margin;
} else if (NS4) {
	if (Math.abs(document.layers[menuName].top + ordinata_margin - ordinata) > thresholdY)
		document.layers[menuName].top = ordinata - ordinata_margin;
} else {
	if (Math.abs(document.all[menuName].style.pixelTop + ordinata_margin - ordinata) > thresholdY)
		document.all[menuName].style.pixelTop = ordinata - ordinata_margin;
}
}
}
}

// -->
</script>

<!-- PHP Layers Menu 1.0.1 (c) 2001 Marco Pratesi <pratesi@telug.it> -->
